@@ -15,15 +15,20 @@
 # TODO: set random.seed explicitly in each test function.
 # See related issue: https://github.com/googleapis/python-api-core/issues/689.
 
-import pytest  # noqa: I202
-import mock
-
 import datetime
 import logging
 import random
 import time
 from typing import List, AsyncIterator
 
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock  # pragma: NO COVER  # noqa: F401
+except ImportError:  # pragma: NO COVER
+    import mock  # type: ignore
+
+import pytest  # noqa: I202
+
 import proto
 
 try:
@@ -287,7 +292,6 @@ async def test_next_escaped_characters_in_string(
 @pytest.mark.asyncio
 @pytest.mark.parametrize("response_type", [EchoResponse, httpbody_pb2.HttpBody])
 async def test_next_not_array(response_type):
-
     data = '{"hello": 0}'
     with mock.patch.object(
         ResponseMock, "content", return_value=mock_async_gen(data)
@@ -347,7 +351,6 @@ async def test_check_buffer(response_type, return_value):
 @pytest.mark.asyncio
 @pytest.mark.parametrize("response_type", [EchoResponse, httpbody_pb2.HttpBody])
 async def test_next_html(response_type):
-
     data = "<!DOCTYPE html><html></html>"
     with mock.patch.object(
         ResponseMock, "content", return_value=mock_async_gen(data)
